@@ -85,6 +85,14 @@ public class ObjectFactory {
         return new GetMultipleData();
     }
 
+    /**
+     * Create an instance of {@link ListByAliasDomain }
+     *
+     */
+    public ListByAliasDomain createListByAliasDomain() {
+        return new ListByAliasDomain();
+    }
+
     /**
      * Create an instance of {@link GetModuleAccess }
      *
@@ -221,6 +229,14 @@ public class ObjectFactory {
         return new ListAllResponse();
     }
 
+    /**
+     * Create an instance of {@link ListByAliasDomainResponse }
+     *
+     */
+    public ListByAliasDomainResponse createListByAliasDomainResponse() {
+        return new ListByAliasDomainResponse();
+    }
+
     /**
      * Create an instance of {@link ChangeByModuleAccess }
      *
